@@ -2,7 +2,7 @@
 
 """Py2SQL.py2sql: provides entry point main()."""
 
-__version__ = "0.2.9"
+__version__ = "0.2.9.1"
 
 import os
 import sqlite3
@@ -10,7 +10,7 @@ from typing import *
 
 import Py2SQL.util_for_db as util
 import Py2SQL.util_for_handle_usual_data as handler
-from .config import *
+from Py2SQL.config import *
 from Py2SQL import sql_queries
 
 
